@@ -1,6 +1,6 @@
 package Hash::Persistent;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 # ABSTRACT: nested hashref serializable to the file
 
 
@@ -116,6 +116,7 @@ sub commit {
     print {$tmp} $serialized or die "print failed: $!";
 
     chmod $_self->{mode}, $tmp_fname if defined $_self->{mode};
+    close $tmp;
     rename $tmp_fname => $fname;
 }
 
@@ -165,13 +166,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hash::Persistent - nested hashref serializable to the file
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -300,7 +303,7 @@ Artyom V. Kulikov <breqwas@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2015 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
